{% for invoice in data %}
invoice:               {{ invoice.number }}
paid:                  {{ invoice.paid_already }}
submitted:             {{ invoice.submitted_on or '' }}
payout due in:         {{ invoice.payout_due_date_relative }}
inv submittal due in:  {% if invoice.submitted_on -%}
N/A
{%- else -%}
  {%- if invoice.submittal_due_from_now_delta.days != 0 -%}
    {{ invoice.submittal_due_from_now_delta.days }}
    {%- if invoice.submittal_due_from_now_delta.days > 1 %} days
    {%- else %} day{% endif %} on {{ invoice.submittal_due_date.strftime("%A %b %-d") }}
  {%- else -%}
    today ({{ invoice.submittal_due_date.strftime("%m-%d") }})
  {% endif %}
{% endif %}
{% endfor -%}
